@@ -25,13 +25,15 @@ read.ctv <- function(file)
     ## set prefixes
     if(prefix) {    
       viewprefix <- "CRAN Task View: "
-      forgeprefix <- "R-Forge Package: "
       biocprefix <- "Bioconductor Package: "
+      forgeprefix <- "R-Forge Project: "
+      googlecodeprefix <- "Google Code Project: "
       target <- " target=\"_top\""
     } else {
       viewprefix <- ""
-      forgeprefix <- ""
       biocprefix <- ""
+      forgeprefix <- ""
+      googlecodeprefix <- ""
       target <- ""
     }
 
@@ -54,6 +56,9 @@ read.ctv <- function(file)
     if(name == "forge")
       return(paste(forgeprefix, "<a href=\"http://R-Forge.R-project.org/projects/",
         xmlValue(x), "/\"", target, "><font color=\"#0076D5\">", xmlValue(x), "</font></a>", sep = ""))
+    if(name == "googlecode")
+      return(paste(googlecodeprefix, "<a href=\"http://code.google.com/p/",
+        xmlValue(x), "/\"", target, "><font color=\"#0076D5\">", xmlValue(x), "</font></a>", sep = ""))
     if(name == "bioc")
       return(paste(biocprefix, "<a href=\"http://www.Bioconductor.org/packages/release/bioc/html/",
         xmlValue(x), ".html\"", target, "><font color=\"#2C92A1\">", xmlValue(x), "</font></a>", sep = ""))
